@@ -85,7 +85,7 @@
 #define PLASMA5SUPPORT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMA5SUPPORT_NO_DEPRECATED
-#  define PLASMA5SUPPORT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60306
+#  define PLASMA5SUPPORT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x6035b
 #endif
 #ifdef PLASMA5SUPPORT_NO_DEPRECATED_WARNINGS
 #  define PLASMA5SUPPORT_DEPRECATED_WARNINGS_SINCE 0
@@ -95,7 +95,7 @@
 #  ifdef PLASMA5SUPPORT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMA5SUPPORT_DEPRECATED_WARNINGS_SINCE PLASMA5SUPPORT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMA5SUPPORT_DEPRECATED_WARNINGS_SINCE 0x60306
+#    define PLASMA5SUPPORT_DEPRECATED_WARNINGS_SINCE 0x6035b
 #  endif
 #endif
 
